require("dotenv").config({ path: "./../.env" });
import mysql from "serverless-mysql";

/**
 * # Main DB Handler Function
 * @async
 *
 * @param {object} params
 * @param {string} params.query
 * @param {string[] | object} [params.values]
 * @param {string} [params.database]
 *
 * @returns {Promise<object|null>}
 */
(async () => {
    const CONNECTION = mysql({
        config: {
            host: process.env.DSQL_DB_HOST,
            user: process.env.DSQL_DB_USERNAME,
            password: process.env.DSQL_DB_PASSWORD,
            database: process.env.DSQL_DB_NAME,
            port: process.env.DSQL_DB_PORT
                ? Number(process.env.DSQL_DB_PORT)
                : undefined,
            charset: "utf8mb4",
        },
    });

    try {
        const result = await CONNECTION.query(
            "SELECT id,first_name,last_name FROM users LIMIT 3"
        );
        console.log("Connection Query Success =>", result);
    } catch (error: any) {
        console.log("Connection query ERROR =>", error.message);
    } finally {
        CONNECTION?.end();
        process.exit();
    }
})();
