import mysql from "serverless-mysql";

/**
 * # DSQL user read-only DB handler
 * @requires DSQL_DB_CONN - Gobal Variable for Datasquirel Database
 */
export default async function DB_HANDLER(...args: any[]) {
    const CONNECTION = mysql({
        config: {
            host: process.env.DSQL_DB_HOST,
            user: process.env.DSQL_DB_USERNAME,
            password: process.env.DSQL_DB_PASSWORD,
            database: process.env.DSQL_DB_NAME,
            port: process.env.DSQL_DB_PORT
                ? Number(process.env.DSQL_DB_PORT)
                : undefined,
            charset: "utf8mb4",
        },
    });

    try {
        if (!CONNECTION)
            throw new Error("No Connection provided to DB_HANDLER function!");

        const results = await CONNECTION.query(...args);

        return JSON.parse(JSON.stringify(results));
    } catch (error: any) {
        console.log("DB Error =>", error);
        return {
            success: false,
            error: error.message,
        };
    } finally {
        await CONNECTION?.end();
    }
}
