import mysql from "serverless-mysql";
import grabDbSSL from "../grabDbSSL";

/**
 * # DSQL user read-only DB handler
 */
export default function NO_DB_HANDLER(...args: any[]) {
    const CONNECTION = mysql({
        config: {
            host: process.env.DSQL_DB_HOST,
            user: process.env.DSQL_DB_USERNAME,
            password: process.env.DSQL_DB_PASSWORD,
            database: process.env.DSQL_DB_NAME,
            port: process.env.DSQL_DB_PORT
                ? Number(process.env.DSQL_DB_PORT)
                : undefined,
            charset: "utf8mb4",
        },
    });

    try {
        return new Promise((resolve, reject) => {
            CONNECTION.query(...args)
                .then((results) => {
                    CONNECTION.end();
                    resolve(JSON.parse(JSON.stringify(results)));
                })
                .catch((err) => {
                    CONNECTION.end();
                    resolve({
                        error: err.message,
                        sql: err.sql,
                    });
                });
        });
    } catch (error: any) {
        return {
            success: false,
            error: error.message,
        };
    } finally {
        CONNECTION?.end();
    }
}
